@@ -4,11 +4,8 @@
 #include <QObject>
 #include <QThread>
 
-#include <MauiKit/Core/fmh.h>
 #include <MauiKit/Core/mauilist.h>
 
-
-class CollectionDB;
 class AlbumsModel : public MauiList
 {
     Q_OBJECT
@@ -28,13 +25,14 @@ public:
     AlbumsModel::QUERY getQuery() const;
 
 private:
-    CollectionDB *db;
     FMH::MODEL_LIST list;
 
     void setList();
 
     AlbumsModel::QUERY query;
 
+    int m_newAlbums;
+
 public slots:
     void refresh();
     int indexOfName(const QString &query);
