@@ -3,10 +3,8 @@
 
 #include <QObject>
 
-#include <MauiKit/Core/fmh.h>
 #include <MauiKit/Core/mauilist.h>
 
-class CollectionDB;
 class TracksModel : public MauiList
 {
     Q_OBJECT
@@ -26,21 +24,21 @@ public:
     void setLimit(int limit);
 
 private:
-    CollectionDB *db;
-
     FMH::MODEL_LIST list;
     QString query;
     int m_limit = 99999;
+    int m_newTracks;
 
     void setList();
 
 signals:
     void queryChanged();
     void limitChanged(int limit);
-    void missingFiles(QStringList urls);
 
 public slots:
     void append(const QVariantMap &item);
+    void appendUrl(const QUrl &url);
+    void appendUrls(const QStringList &urls);
     void appendAt(const QVariantMap &item, const int &at);
     void appendQuery(const QString &query);
     void copy(const TracksModel *list);
@@ -49,13 +47,14 @@ public slots:
     bool fav(const int &index, const bool &value);
     bool countUp(const int &index);
     bool remove(const int &index);
-
-    void removeMissingFiles(const QStringList &urls);
+    bool removeMissing(const int &index);
 
     void refresh();
     bool update(const QVariantMap &data, const int &index);
     
     void updateMetadata(const QVariantMap &data, const int &index);
+
+    QStringList urls() const;
 };
 
 #endif // TRACKSMODEL_H
