@@ -1,4 +1,4 @@
-.import org.maui.vvave 1.0 as Vvave
+.import org.mauikit.filebrowsing 1.3 as FB
 
 function playTrack()
 {
@@ -54,11 +54,15 @@ function quickPlay(track)
 
 function appendTracksAt(tracks, at)
 {
-    if(tracks)
-        for(var i in tracks)
-        {
-            mainPlaylist.listModel.list.appendAt(tracks[i], parseInt(at)+parseInt(i))
-        }
+    for(var i in tracks)
+    {
+        mainPlaylist.listModel.list.appendAt(tracks[i], parseInt(at)+parseInt(i))
+    }
+}
+
+function appendUrls(urls)
+{
+    mainPlaylist.listModel.list.appendUrls(urls)
 }
 
 function appendTrack(track)
@@ -68,7 +72,7 @@ function appendTrack(track)
         playlist.append(track)
         if(sync === true)
         {
-           Vvave.Playlists.addTrack(syncPlaylist, [track.url])
+           FB.Tagging.tagUrl(track.url, syncPlaylist)
         }
     }
 }
@@ -90,11 +94,6 @@ function appendAll(tracks)
     mainPlaylist.listView.positionViewAtEnd()
 }
 
-function savePlaylist()
-{
-   playlist.save()
-}
-
 function playAll(tracks)
 {
     sync = false
@@ -116,7 +115,6 @@ function appendAllModel(model)
    mainPlaylist.listView.positionViewAtEnd()
 }
 
-
 function playAllModel(model)
 {
     sync = false
