@@ -7,13 +7,15 @@
 #include <MauiKit/FileBrowsing/fm.h>
 #include <MauiKit/Core/utils.h>
 
-#include <QTimer>
+#include "utils/bae.h"
 
-static FMH::MODEL trackInfo(const QUrl &url)
+FMH::MODEL vvave::trackInfo(const QUrl &url)
 {
     TagInfo info(url.toLocalFile());
     if (info.isNull())
+    {
         return FMH::MODEL();
+    }
 
     const auto track = info.getTrack();
     const auto genre = info.getGenre();
@@ -25,7 +27,7 @@ static FMH::MODEL trackInfo(const QUrl &url)
     const auto year = info.getYear();
     const auto comment = info.getComment();
 
-    FMH::MODEL map = {{FMH::MODEL_KEY::URL, url.toString()},
+    return FMH::MODEL {{FMH::MODEL_KEY::URL, url.toString()},
                       {FMH::MODEL_KEY::TRACK, QString::number(track)},
                       {FMH::MODEL_KEY::TITLE, title},
                       {FMH::MODEL_KEY::ARTIST, artist},
@@ -35,9 +37,13 @@ static FMH::MODEL trackInfo(const QUrl &url)
                       {FMH::MODEL_KEY::GENRE, genre},
                       {FMH::MODEL_KEY::SOURCE, sourceUrl},
                       {FMH::MODEL_KEY::RELEASEDATE, QString::number(year)}};
+}
 
-    BAE::artworkCache(map, FMH::MODEL_KEY::ALBUM);
-    return map;
+QVariantList vvave::pendingTracks()
+{
+    auto res = m_pendingTracks;
+    m_pendingTracks.clear();
+    return res;
 }
 
 /*
@@ -48,68 +54,12 @@ static FMH::MODEL trackInfo(const QUrl &url)
  * */
 vvave::vvave(QObject *parent)
     : QObject(parent)
-    , db(CollectionDB::getInstance())
 {
     qRegisterMetaType<QList<QUrl> *>("QList<QUrl>&");
 
     QDir dirPath(BAE::CachePath.toLocalFile());
     if (!dirPath.exists())
         dirPath.mkpath(".");
-
-    auto tracksTimer = new QTimer(this);
-    tracksTimer->setSingleShot(true);
-    tracksTimer->setInterval(1000);
-
-    auto albumsTimer = new QTimer(this);
-    albumsTimer->setSingleShot(true);
-    albumsTimer->setInterval(1000);
-
-    auto artistTimer = new QTimer(this);
-    artistTimer->setSingleShot(true);
-    artistTimer->setInterval(1000);
-
-    connect(db, &CollectionDB::trackInserted, [this, tracksTimer](QVariantMap) {
-        m_newTracks++;
-        tracksTimer->start();
-    });
-
-    connect(db, &CollectionDB::albumInserted, [this, albumsTimer](QVariantMap) {
-        m_newAlbums++;
-        albumsTimer->start();
-    });
-
-    connect(db, &CollectionDB::artistInserted, [this, artistTimer](QVariantMap) {
-        m_newArtist++;
-        artistTimer->start();
-    });
-
-    connect(db, &CollectionDB::sourceInserted, [this](QVariantMap) {
-        m_newSources++;
-    });
-
-    connect(tracksTimer, &QTimer::timeout, [this]()
-    {
-        if (m_newTracks > 0) {
-            emit tracksAdded(m_newTracks);
-            m_newTracks = 0;
-        }
-    });
-
-    connect(albumsTimer, &QTimer::timeout, [this]()
-    {
-        if (m_newAlbums > 0) {
-            emit albumsAdded(m_newAlbums);
-            m_newAlbums = 0;
-        }
-    });
-
-    connect(artistTimer, &QTimer::timeout, [this]()
-    {
-        if (m_newArtist > 0) {
-            emit artistsAdded(m_newArtist);
-            m_newArtist = 0;
-        }
-    });
 }
 
 void vvave::setFetchArtwork(bool fetchArtwork)
@@ -121,11 +71,6 @@ void vvave::setFetchArtwork(bool fetchArtwork)
     emit fetchArtworkChanged(m_fetchArtwork);
 }
 
-bool vvave::autoScan() const
-{
-    return m_autoScan;
-}
-
 bool vvave::fetchArtwork() const
 {
     return m_fetchArtwork;
@@ -163,7 +108,7 @@ bool vvave::removeSource(const QString &source)
     UTIL::saveSettings("SETTINGS", QVariant::fromValue(urls), "SOURCES");
     emit sourcesChanged();
 
-    if (this->db->removeSource(source)) {
+    if (CollectionDB::getInstance()->removeSource(source)) {
         emit this->sourceRemoved(source);
         return true;
     }
@@ -177,7 +122,7 @@ void vvave::scanDir(const QList<QUrl> &paths)
     fileLoader->informer = &trackInfo;
     //    fileLoader->setBatchCount(50);
 
-    connect(fileLoader, &FMH::FileLoader::itemReady, db, &CollectionDB::addTrack);
+    connect(fileLoader, &FMH::FileLoader::itemReady, CollectionDB::getInstance(), &CollectionDB::addTrack);
     connect(fileLoader, &FMH::FileLoader::finished, fileLoader, [this, fileLoader](FMH::MODEL_LIST, QList<QUrl>)
     {
         m_scanning = false;
@@ -192,6 +137,11 @@ void vvave::scanDir(const QList<QUrl> &paths)
     emit scanningChanged(m_scanning);
 }
 
+void vvave::rescan()
+{
+    scanDir(QUrl::fromStringList(sources()));
+}
+
 QStringList vvave::sources()
 {
     return UTIL::loadSettings("SETTINGS", "SOURCES", QVariant::fromValue(BAE::defaultSources)).toStringList();
@@ -209,37 +159,20 @@ QVariantList vvave::sourcesModel()
     return res;
 }
 
-void vvave::setAutoScan(bool autoScan)
-{
-    if (m_autoScan == autoScan)
-        return;
-
-    m_autoScan = autoScan;
-    emit autoScanChanged(m_autoScan);
-
-    if (m_autoScan) {
-        scanDir(QUrl::fromStringList(sources()));
-    }
-}
-
 void vvave::openUrls(const QStringList &urls)
 {
     if (urls.isEmpty())
         return;
 
-    QVariantList data;
-
     for (const auto &url : urls) {
         auto _url = QUrl::fromUserInput(url);
-        if (db->check_existance(BAE::TABLEMAP[BAE::TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::URL], _url.toString())) {
-            const auto item = this->db->getDBData(QStringList() << _url.toString());
-            data << FMH::toMap(item.first());
+        if (CollectionDB::getInstance()->check_existance(BAE::TABLEMAP[BAE::TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::URL], _url.toString())) {
+            const auto item = CollectionDB::getInstance()->getDBData(QStringList() << _url.toString());
+            m_pendingTracks << FMH::toMap(item.first());
         } else {
-            data << FMH::toMap(trackInfo(_url));
+            m_pendingTracks << FMH::toMap(trackInfo(_url));
         }
     }
-
-    emit this->openFiles(data);
 }
 
 QList<QUrl> vvave::folders()
